==> xfdashboard_0.5.0.orig.tar.bz2: xfdashboard-0.5.0/xfdashboard/enums.h <==

/* Generated data (by glib-mkenums) */

/*
 * enums: Definitions of enumerations and flags used in GObject objects
 * 
 * Copyrigt 2012-2015 Stephan Haller <nomad@froevel.de>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 * 
 */

#ifndef __XFDASHBOARD_ENUMS__
#define __XFDASHBOARD_ENUMS__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "binding.h" */
GType xfdashboard_binding_flags_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BINDING_FLAGS	(xfdashboard_binding_flags_get_type())

/* enumerations from "bindings-pool.h" */
GType xfdashboard_bindings_pool_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BINDINGS_POOL_ERROR_ENUM	(xfdashboard_bindings_pool_error_enum_get_type())

/* enumerations from "image-content.h" */
GType xfdashboard_image_content_loading_state_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_IMAGE_CONTENT_LOADING_STATE	(xfdashboard_image_content_loading_state_get_type())

/* enumerations from "theme.h" */
GType xfdashboard_theme_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_ERROR_ENUM	(xfdashboard_theme_error_enum_get_type())

/* enumerations from "theme-css.h" */
GType xfdashboard_theme_css_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_CSS_ERROR_ENUM	(xfdashboard_theme_css_error_enum_get_type())

/* enumerations from "theme-effects.h" */
GType xfdashboard_theme_effects_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_EFFECTS_ERROR_ENUM	(xfdashboard_theme_effects_error_enum_get_type())

/* enumerations from "theme-layout.h" */
GType xfdashboard_theme_layout_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_LAYOUT_ERROR_ENUM	(xfdashboard_theme_layout_error_enum_get_type())

/* enumerations from "types.h" */
GType xfdashboard_view_mode_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_VIEW_MODE	(xfdashboard_view_mode_get_type())
GType xfdashboard_policy_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_POLICY	(xfdashboard_policy_get_type())
GType xfdashboard_style_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_STYLE	(xfdashboard_style_get_type())
GType xfdashboard_orientation_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_ORIENTATION	(xfdashboard_orientation_get_type())
GType xfdashboard_background_type_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BACKGROUND_TYPE	(xfdashboard_background_type_get_type())
GType xfdashboard_corners_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_CORNERS	(xfdashboard_corners_get_type())
GType xfdashboard_borders_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BORDERS	(xfdashboard_borders_get_type())
GType xfdashboard_fit_mode_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_FIT_MODE	(xfdashboard_fit_mode_get_type())
GType xfdashboard_stage_background_image_type_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_STAGE_BACKGROUND_IMAGE_TYPE	(xfdashboard_stage_background_image_type_get_type())
GType xfdashboard_selection_target_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_SELECTION_TARGET	(xfdashboard_selection_target_get_type())
GType xfdashboard_anchor_point_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_ANCHOR_POINT	(xfdashboard_anchor_point_get_type())
G_END_DECLS

#endif

/* Generated data ends here */

==> xfdashboard-0.5.4.tar.bz2: xfdashboard-0.5.4/xfdashboard/enums.h <==

/* Generated data (by glib-mkenums) */

/*
 * enums: Definitions of enumerations and flags used in GObject objects
 * 
 * Copyrigt 2012-2015 Stephan Haller <nomad@froevel.de>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 * 
 */

#ifndef __XFDASHBOARD_ENUMS__
#define __XFDASHBOARD_ENUMS__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "background.h" */
GType xfdashboard_background_type_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BACKGROUND_TYPE	(xfdashboard_background_type_get_type())

/* enumerations from "binding.h" */
GType xfdashboard_binding_flags_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BINDING_FLAGS	(xfdashboard_binding_flags_get_type())

/* enumerations from "bindings-pool.h" */
GType xfdashboard_bindings_pool_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BINDINGS_POOL_ERROR_ENUM	(xfdashboard_bindings_pool_error_enum_get_type())

/* enumerations from "button.h" */
GType xfdashboard_button_style_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BUTTON_STYLE	(xfdashboard_button_style_get_type())

/* enumerations from "image-content.h" */
GType xfdashboard_image_content_loading_state_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_IMAGE_CONTENT_LOADING_STATE	(xfdashboard_image_content_loading_state_get_type())

/* enumerations from "plugin.h" */
GType xfdashboard_plugin_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_PLUGIN_ERROR_ENUM	(xfdashboard_plugin_error_enum_get_type())

/* enumerations from "theme.h" */
GType xfdashboard_theme_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_ERROR_ENUM	(xfdashboard_theme_error_enum_get_type())

/* enumerations from "theme-css.h" */
GType xfdashboard_theme_css_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_CSS_ERROR_ENUM	(xfdashboard_theme_css_error_enum_get_type())

/* enumerations from "theme-effects.h" */
GType xfdashboard_theme_effects_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_EFFECTS_ERROR_ENUM	(xfdashboard_theme_effects_error_enum_get_type())

/* enumerations from "theme-layout.h" */
GType xfdashboard_theme_layout_error_enum_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_THEME_LAYOUT_ERROR_ENUM	(xfdashboard_theme_layout_error_enum_get_type())

/* enumerations from "types.h" */
GType xfdashboard_view_mode_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_VIEW_MODE	(xfdashboard_view_mode_get_type())
GType xfdashboard_visibility_policy_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_VISIBILITY_POLICY	(xfdashboard_visibility_policy_get_type())
GType xfdashboard_orientation_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_ORIENTATION	(xfdashboard_orientation_get_type())
GType xfdashboard_corners_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_CORNERS	(xfdashboard_corners_get_type())
GType xfdashboard_borders_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_BORDERS	(xfdashboard_borders_get_type())
GType xfdashboard_stage_background_image_type_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_STAGE_BACKGROUND_IMAGE_TYPE	(xfdashboard_stage_background_image_type_get_type())
GType xfdashboard_selection_target_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_SELECTION_TARGET	(xfdashboard_selection_target_get_type())
GType xfdashboard_anchor_point_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_ANCHOR_POINT	(xfdashboard_anchor_point_get_type())

/* enumerations from "view.h" */
GType xfdashboard_view_fit_mode_get_type(void) G_GNUC_CONST;
#define XFDASHBOARD_TYPE_VIEW_FIT_MODE	(xfdashboard_view_fit_mode_get_type())
G_END_DECLS

#endif

/* Generated data ends here */
